==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/th-TH/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'เช็คอินอุปกรณ์เสริมแล้ว',
    'Accessory_Checkout_Notification' => 'Accessory checked out',
    'Asset_Checkin_Notification' => 'เช็คอินสินทรัพย์แล้ว',
    'Asset_Checkout_Notification' => 'Asset checked out',
    'Confirm_Accessory_Checkin' => 'ยืนยันการเช็คอินอุปกรณ์เสริม',
    'Confirm_Asset_Checkin' => 'ยืนยันการเช็คอินสินทรัพย์',
    'Confirm_accessory_delivery' => 'ยืนยันการจัดส่งอุปกรณ์เสริม',
    'Confirm_asset_delivery' => 'ยืนยันการจัดส่งสินทรัพย์',
    'Confirm_consumable_delivery' => 'ยืนยันการจัดส่งวัสดุสิ้นเปลือง',
    'Confirm_license_delivery' => 'การยืนยันการส่งมอบใบอนุญาต',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Days' => 'วัน',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'เตือนความจำ :: ใกล้หมดเวลาเช็คอิน',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'รายงานสินทรัพย์หมดอายุ',
    'Expiring_Licenses_Report' => 'รายงานใบอนุญาตหมดอายุ',
    'Item_Request_Canceled' => 'ขอรายการถูกยกเลิกแล้ว',
    'Item_Requested' => 'รายการที่ขอ',
    'License_Checkin_Notification' => 'เช็คอินใบอนุญาตแล้ว',
    'License_Checkout_Notification' => 'License checked out',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'รายงานพื้นที่โฆษณาต่ำ',
    'a_user_canceled' => 'ผู้ใช้ยกเลิกคำร้องขอสินค้าในเว็บไซต์แล้ว',
    'a_user_requested' => 'ผู้ใช้ร้องขอรายการบนเว็บไซต์',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'accessory_name' => 'ชื่ออุปกรณ์เสริม',
    'additional_notes' => 'หมายเหตุเพิ่มเติม',
    'admin_has_created' => 'ผู้ดูแลระบบได้สร้างบัญชีให้กับคุณบนเว็บไซต์: web',
    'asset' => 'สินทรัพย์',
    'asset_name' => 'ชื่อสินทรัพย์',
    'asset_requested' => 'สินทรัพย์ที่ขอ',
    'asset_tag' => 'แท็กทรัพย์สิน',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'assigned_to' => 'ได้รับมอบหมายให้',
    'best_regards' => 'ด้วยความเคารพ,',
    'canceled' => 'ยกเลิก',
    'checkin_date' => 'วันที่เช็คอิน',
    'checkout_date' => 'ชำระเงินวันที่',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'โปรดคลิกที่ลิงค์ด้านล่างเพื่อยืนยันว่าคุณได้รับอุปกรณ์เสริมแล้ว',
    'click_on_the_link_asset' => 'โปรดคลิกลิงก์ที่ด้านล่างเพื่อยืนยันว่าคุณได้รับเนื้อหาแล้ว',
    'click_to_confirm' => 'โปรดคลิกลิงก์ต่อไปนี้เพื่อยืนยันข้อมูล: บัญชีเว็บ:',
    'current_QTY' => 'QTY ปัจจุบัน',
    'days' => 'วัน',
    'expecting_checkin_date' => 'วันที่เช็คอินที่คาดหวังไว้',
    'expires' => 'วันที่หมดอายุ',
    'hello' => 'สวัสดี',
    'hi' => 'สวัสดี',
    'i_have_read' => 'ฉันได้อ่านและยอมรับข้อกำหนดในการให้บริการแล้วและได้รับสินค้านี้แล้ว',
    'inventory_report' => 'Inventory Report',
    'item' => 'รายการ',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'มี: ใบอนุญาตที่จะหมดอายุในวันถัดไป: วันที่กำหนด|มี: ใบอนุญาตที่จะหมดอายุในวันถัดไป: วันที่กำหนด',
    'link_to_update_password' => 'โปรดคลิกลิงก์ต่อไปนี้เพื่ออัปเดต: รหัสผ่านเว็บ:',
    'login' => 'เข้าสู่ระบบ',
    'login_first_admin' => 'เข้าสู่ระบบการติดตั้ง Snipe-IT ใหม่ของคุณโดยใช้ข้อมูลรับรองด้านล่าง:',
    'low_inventory_alert' => 'มี: นับสินค้าที่ต่ำกว่าสินค้าคงคลังขั้นต่ำหรือเร็ว ๆ นี้จะต่ำ|มี: นับสินค้าที่ต่ำกว่าสินค้าคงคลังขั้นต่ำหรือจะเร็วเกินไป',
    'min_QTY' => 'Min QTY',
    'name' => 'ชื่อ',
    'new_item_checked' => 'รายการใหม่ได้รับการตรวจสอบภายใต้ชื่อของคุณแล้วรายละเอียดมีดังนี้',
    'notes' => 'จดบันทึก',
    'password' => 'รหัสผ่าน',
    'password_reset' => 'รีเซ็ตรหัสผ่าน',
    'read_the_terms' => 'โปรดอ่านเงื่อนไขการใช้งานด้านล่างนี้',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'คำร้องขอ',
    'reset_link' => 'ลิงก์รีเซ็ตรหัสผ่านของคุณ',
    'reset_password' => 'คลิกที่นี่เพื่อรีเซ็ตรหัสผ่าน:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'หมายเลขผลิตภัณฑ์',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'ผู้ผลิต',
    'tag' => 'แท็ก',
    'test_email' => 'ทดสอบอีเมลจาก Snipe-IT',
    'test_mail_text' => 'นี่เป็นการทดสอบจาก Snipe-IT Asset Management System ถ้าคุณได้รับอีเมลนี้จะทำงาน :)',
    'the_following_item' => 'รายการต่อไปนี้ได้รับการตรวจสอบใน:',
    'to_reset' => 'ในการรีเซ็ตรหัสผ่านเว็บของคุณโปรดกรอกแบบฟอร์มนี้:',
    'type' => 'ชนิด',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'ผู้ใช้งาน',
    'username' => 'ชื่อผู้ใช้',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'ยินดีต้อนรับ: ชื่อ',
    'welcome_to' => 'ยินดีต้อนรับสู่: web!',
    'your_assets' => 'ดูสินทรัพย์ที่มี',
    'your_credentials' => 'ข้อมูลรับรอง Snipe-IT ของคุณ',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/th-TH/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'เช็คอินอุปกรณ์เสริมแล้ว',
    'Accessory_Checkout_Notification' => 'Accessory checked out|:count Accessories checked out',
    'Asset_Checkin_Notification' => 'Asset checked in: :tag',
    'Asset_Checkout_Notification' => 'Asset checked out: :tag',
    'Confirm_Accessory_Checkin' => 'ยืนยันการเช็คอินอุปกรณ์เสริม',
    'Confirm_Asset_Checkin' => 'ยืนยันการเช็คอินสินทรัพย์',
    'Confirm_component_checkin' => 'Component checkin confirmation',
    'Confirm_accessory_delivery' => 'ยืนยันการจัดส่งอุปกรณ์เสริม',
    'Confirm_asset_delivery' => 'ยืนยันการจัดส่งสินทรัพย์',
    'Confirm_consumable_delivery' => 'ยืนยันการจัดส่งวัสดุสิ้นเปลือง',
    'Confirm_component_delivery' => 'Component delivery confirmation',
    'Confirm_license_delivery' => 'การยืนยันการส่งมอบใบอนุญาต',
    'Consumable_checkout_notification' => 'Consumable checked out',
    'Component_checkout_notification' => 'Component checked out',
    'Component_checkin_notification' => 'Component checked in',
    'Days' => 'วัน',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'Expected_Checkin_Notification' => 'เตือนความจำ :: ใกล้หมดเวลาเช็คอิน',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expiring_Assets_Report' => 'Expiring Assets Report',
    'Expiring_Licenses_Report' => 'Expiring Licenses Report',
    'Item_Request_Canceled' => 'ขอรายการถูกยกเลิกแล้ว',
    'Item_Requested' => 'รายการที่ขอ',
    'License_Checkin_Notification' => 'เช็คอินใบอนุญาตแล้ว',
    'License_Checkout_Notification' => 'License checked out',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'รายงานพื้นที่โฆษณาต่ำ',
    'a_user_canceled' => 'ผู้ใช้ยกเลิกคำร้องขอสินค้าในเว็บไซต์แล้ว',
    'a_user_requested' => 'ผู้ใช้ร้องขอรายการบนเว็บไซต์',
    'acceptance_asset_accepted_to_user' => 'You have accepted an item assigned to you by :site_name|You have accepted :qty items assigned to you by :site_name',
    'acceptance_asset_accepted' => 'A user has accepted an item',
    'acceptance_asset_declined' => 'A user has declined an item',
    'send_pdf_copy' => 'Send a copy of this acceptance to my email address',
    'accessory_name' => 'ชื่ออุปกรณ์เสริม',
    'additional_notes' => 'หมายเหตุเพิ่มเติม',
    'admin_has_created' => 'An administrator has created an account for you on the :web website. Please find your username below, and click on the link to set a password.',
    'asset' => 'สินทรัพย์',
    'asset_name' => 'ชื่อสินทรัพย์',
    'asset_requested' => 'สินทรัพย์ที่ขอ',
    'asset_tag' => 'แท็กทรัพย์สิน',
    'assets_warrantee_alert' => 'There is :count asset with an expiring warranty or that are reaching their end of life in the next :threshold days.|There are :count assets with expiring warranties or that are reaching their end of life in the next :threshold days.',
    'assigned_to' => 'ได้รับมอบหมายให้',
    'eol' => 'อายุการใช้งาน',
    'best_regards' => 'ด้วยความเคารพ,',
    'canceled' => 'ยกเลิก',
    'checkin_date' => 'วันที่เช็คอิน',
    'checkout_date' => 'ชำระเงินวันที่',
    'checkedout_from' => 'Checked out from',
    'checkedin_from'  => 'Checked in from',
    'checked_into' => 'Checked into',
    'click_on_the_link_accessory' => 'โปรดคลิกที่ลิงค์ด้านล่างเพื่อยืนยันว่าคุณได้รับอุปกรณ์เสริมแล้ว',
    'click_on_the_link_asset' => 'โปรดคลิกลิงก์ที่ด้านล่างเพื่อยืนยันว่าคุณได้รับเนื้อหาแล้ว',
    'click_to_confirm' => 'โปรดคลิกลิงก์ต่อไปนี้เพื่อยืนยันข้อมูล: บัญชีเว็บ:',
    'current_QTY' => 'QTY ปัจจุบัน',
    'days' => 'วัน',
    'expecting_checkin_date' => 'วันที่เช็คอินที่คาดหวังไว้',
    'expires' => 'วันที่หมดอายุ',
    'terminates' => 'Terminates',
    'following_accepted' => 'The following was accepted',
    'following_declined' => 'The following was declined',
    'hello' => 'สวัสดี',
    'hi' => 'สวัสดี',
    'i_have_read' => 'ฉันได้อ่านและยอมรับข้อกำหนดในการให้บริการแล้วและได้รับสินค้านี้แล้ว',
    'initiated_accepted' => 'A checkout you initiated was accepted',
    'initiated_declined' => 'A checkout you initiated was declined',
    'inventory_report' => 'Inventory Report',
    'item' => 'รายการ',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring or terminating in the next :threshold days.|There are :count licenses expiring or terminating in the next :threshold days.',
    'link_to_update_password' => 'โปรดคลิกลิงก์ต่อไปนี้เพื่ออัปเดต: รหัสผ่านเว็บ:',
    'login' => 'เข้าสู่ระบบ',
    'login_first_admin' => 'เข้าสู่ระบบการติดตั้ง Snipe-IT ใหม่ของคุณโดยใช้ข้อมูลรับรองด้านล่าง:',
    'low_inventory_alert' => 'มี: นับสินค้าที่ต่ำกว่าสินค้าคงคลังขั้นต่ำหรือเร็ว ๆ นี้จะต่ำ|มี: นับสินค้าที่ต่ำกว่าสินค้าคงคลังขั้นต่ำหรือจะเร็วเกินไป',
    'min_QTY' => 'Min QTY',
    'name' => 'ชื่อ',
    'new_item_checked' => 'A new item has been checked out under your name, details are below.|:count new items have been checked out under your name, details are below.',
    'new_item_checked_with_acceptance' => 'A new item has been checked out under your name that requires acceptance, details are below.|:count new items have been checked out under your name that requires acceptance, details are below.',
    'new_item_checked_location' => 'A new item has been checked out to :location, details are below.|:count new items have been checked out to :location, details are below.',
    'recent_item_checked' => 'An item was recently checked out under your name that requires acceptance, details are below.',
    'notes' => 'จดบันทึก',
    'password' => 'รหัสผ่าน',
    'password_reset' => 'รีเซ็ตรหัสผ่าน',
    'read_the_terms' => 'โปรดอ่านเงื่อนไขการใช้งานด้านล่างนี้',
    'read_the_terms_and_click' => 'Please read the terms of use below, and click on the link at the bottom to confirm that you read and agree to the terms of use, and have received the asset.',
    'requested' => 'คำร้องขอ',
    'reset_link' => 'ลิงก์รีเซ็ตรหัสผ่านของคุณ',
    'reset_password' => 'คลิกที่นี่เพื่อรีเซ็ตรหัสผ่าน:',
    'rights_reserved' => 'All rights reserved.',
    'serial' => 'หมายเลขผลิตภัณฑ์',
    'snipe_webhook_test' => 'Snipe-IT Integration Test',
    'snipe_webhook_summary' => 'Snipe-IT Integration Test Summary',
    'supplier' => 'ผู้ผลิต',
    'tag' => 'แท็ก',
    'test_email' => 'ทดสอบอีเมลจาก Snipe-IT',
    'test_mail_text' => 'นี่เป็นการทดสอบจาก Snipe-IT Asset Management System ถ้าคุณได้รับอีเมลนี้จะทำงาน :)',
    'the_following_item' => 'รายการต่อไปนี้ได้รับการตรวจสอบใน:',
    'to_reset' => 'ในการรีเซ็ตรหัสผ่านเว็บของคุณโปรดกรอกแบบฟอร์มนี้:',
    'type' => 'ชนิด',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'ผู้ใช้งาน',
    'username' => 'ชื่อผู้ใช้',
    'unaccepted_asset_reminder' => 'Reminder: You have Unaccepted Assets.',
    'welcome' => 'ยินดีต้อนรับ: ชื่อ',
    'welcome_to' => 'ยินดีต้อนรับสู่: web!',
    'your_assets' => 'ดูสินทรัพย์ที่มี',
    'your_credentials' => 'ข้อมูลรับรอง Snipe-IT ของคุณ',
    'mail_sent' => 'Mail sent successfully!',
];
